if not RazerNagaConfig then return end

local debug = false

local T = LibStub( "WAR-AceLocale-3.0" ) : GetLocale( "RazerNaga", debug )
local LibGUI 	= LibStub( "LibGUI" )

local initialized		= false

local InitializeWindow, ApplyConfigSettings, RevertConfigSettings, UpdateOrientationButton
local window	= {
	Name		= T[""],
	display		= {},
	W			= {},
}

local db

local Texture_H2V = "RazerNaga_H2V"
local Texture_V2H = "RazerNaga_V2H"

function InitializeWindow()
	-- If our window already exists, we are all set
	if initialized then return end
	
	local w
	local e	
	
	-- Store our db here
	db = RazerNaga.db.profile
	
	-- General Window
	w = LibGUI( "window", nil, "RazerNagaWindowDefault" )
	w:ClearAnchors()
	w:Resize( 300, 195 )
	w:Show( true )
	window.W.General = w
	
	-- This is the order the windows are displayed to the user
	table.insert( window.display, window.W.General )
	
	--
	-- GENERAL WINDOW
	--
	-- General - Mode Label
    e = window.W.General( "Label" )
    e:Resize( 300 )
    e:Align( "leftcenter" )
    e:AnchorTo( window.W.General, "topleft", "topleft", 15, 10 )
    e:Font( "font_chat_text" )
    e:SetText( T["Mode:"] )
    window.W.General.Mode_Label = e
    
    -- General - Mode Combo
    e = window.W.General( "combobox", nil, "RazerNagaComboBox_General_Mode" )
    e:AnchorTo( window.W.General.Mode_Label, "bottomleft", "topleft", 0, 0 )
    for _, mode in ipairs( RazerNaga.MODES ) 
	do 
		e:Add( mode.desc )
	end
    window.W.General.Mode_Combo = e
    
    -- General - Rows Button
    e = window.W.General( "button", nil, "EA_Button_DefaultIconFrame" )
    e:AnchorTo( window.W.General.Mode_Combo, "bottomright", "bottomleft", 10, 0 )
    e.OnLButtonUp =
		function()
			local stayDownFlag = ButtonGetStayDownFlag( window.W.General.Rows_Button.name )
			
			local rows = 4
			if( stayDownFlag ) then
				rows = 3
			end
			RazerNaga.UpdateRows( 1, rows )
			UpdateRowsButton( not stayDownFlag )
		end		
    window.W.General.Rows_Button = e
    
    -- General - Automatic Keybinding Checkbox
	e = window.W.General( "Checkbox" )
	e:AnchorTo( window.W.General.Mode_Combo, "bottomleft", "topleft", 0, 10 )
	e.OnLButtonUp =
		function()
			RazerNaga.UpdateAutomaticKeybinding( window.W.General.AutomaticKeybinding_Checkbox:GetValue() )
		end		
	window.W.General.AutomaticKeybinding_Checkbox = e
    
    -- General - Automatic Keybinding Label
    e = window.W.General( "Label" )
    e:Resize( 300 )
    e:Align( "leftcenter" )
    e:AnchorTo( window.W.General.AutomaticKeybinding_Checkbox, "right", "left", 10, 0 )
    e:Font( "font_chat_text" )
    e:SetText( T["Enable Automatic Keybinding"] )
    window.W.General.AutomaticKeybinding_Label = e
    
    -- General - Right Click Options Label
    e = window.W.General( "Label" )
    e:Resize( 300, 60 )
    e:Align( "center" )
    e:AnchorTo( window.W.General, "bottom", "bottom", -25, 0 )
    e:Font( "font_chat_text" )
    e:Color( 255, 255, 255 )
    e:WordWrap( true )
    e:SetText( T["You may right click on an action bar for more options."] )
    window.W.General.RightClickOptions_Label = e
    
    initialized = true
end

function RazerNagaConfig_General_OnModeSelectionChanged()
	RazerNaga.UpdateMode( window.W.General.Mode_Combo:SelectedIndex() )
end

function UpdateRowsButton( flagged )
	local windowId = window.W.General.Rows_Button.name
	
	-- True - Horizontal
	-- False - Vertical

	-- We want the texture to be opposite the currently flagged orientation
	local texture = Texture_H2V
	if( flagged ) then
		texture = Texture_V2H
	end
	
	ButtonSetStayDownFlag( windowId, flagged )
	ButtonSetPressedFlag( windowId, flagged )

	DynamicImageSetTexture( windowId .. "Icon", texture, 64, 64 )
end

function ApplyConfigSettings()
end

function RevertConfigSettings()
	window.W.General.Mode_Combo:SelectIndex( db.general.mode )
	window.W.General.AutomaticKeybinding_Checkbox:SetValue( db.general.automatickeybinding )
	
	local buttonCount 	= ActionBarClusterManager.m_Settings:GetActionBarSetting( 1, "buttonCount" )
	local columns		= ActionBarClusterManager.m_Settings:GetActionBarSetting( 1, "columns" )
	local rows = buttonCount / columns
	UpdateRowsButton( rows == 4 )
end

window.Initialize	= InitializeWindow
window.Apply		= ApplyConfigSettings
window.Revert		= RevertConfigSettings
window.Index		= RazerNagaConfig.RegisterWindow( window )